@@ -84,7 +84,7 @@
 #define KFILEMETADATA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KFILEMETADATA_NO_DEPRECATED
-#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KFILEMETADATA_NO_DEPRECATED_WARNINGS
 #  define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
